<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyOtherDetailRequest;
use App\Http\Requests\StoreOtherDetailRequest;
use App\Http\Requests\UpdateOtherDetailRequest;
use App\Models\OtherDetail;
use Gate;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;

class OtherDetailController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('other_detail_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $otherDetails = OtherDetail::with(['media'])->get();

        return view('admin.otherDetails.index', compact('otherDetails'));
    }

    public function create()
    {
        abort_if(Gate::denies('other_detail_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.otherDetails.create');
    }

    public function store(StoreOtherDetailRequest $request)
    {
        $otherDetail = OtherDetail::create($request->all());

        if ($request->input('icon', false)) {
            $otherDetail->addMedia(storage_path('tmp/uploads/' . basename($request->input('icon'))))->toMediaCollection('icon');
        }

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $otherDetail->id]);
        }

        return redirect()->route('admin.other-details.index');
    }

    public function edit(OtherDetail $otherDetail)
    {
        abort_if(Gate::denies('other_detail_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.otherDetails.edit', compact('otherDetail'));
    }

    public function update(UpdateOtherDetailRequest $request, OtherDetail $otherDetail)
    {
        $otherDetail->update($request->all());

        if ($request->input('icon', false)) {
            if (! $otherDetail->icon || $request->input('icon') !== $otherDetail->icon->file_name) {
                if ($otherDetail->icon) {
                    $otherDetail->icon->delete();
                }
                $otherDetail->addMedia(storage_path('tmp/uploads/' . basename($request->input('icon'))))->toMediaCollection('icon');
            }
        } elseif ($otherDetail->icon) {
            $otherDetail->icon->delete();
        }

        return redirect()->route('admin.other-details.index');
    }

    public function show(OtherDetail $otherDetail)
    {
        abort_if(Gate::denies('other_detail_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.otherDetails.show', compact('otherDetail'));
    }

    public function destroy(OtherDetail $otherDetail)
    {
        abort_if(Gate::denies('other_detail_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $otherDetail->delete();

        return back();
    }

    public function massDestroy(MassDestroyOtherDetailRequest $request)
    {
        $otherDetails = OtherDetail::find(request('ids'));

        foreach ($otherDetails as $otherDetail) {
            $otherDetail->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        abort_if(Gate::denies('other_detail_create') && Gate::denies('other_detail_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new OtherDetail();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
}
