<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyRtoOfficRequest;
use App\Http\Requests\StoreRtoOfficRequest;
use App\Http\Requests\UpdateRtoOfficRequest;
use App\Models\RtoOffic;
use App\Models\State;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class RtoOfficController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('rto_offic_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rtoOffics = RtoOffic::with(['state'])->get();

        return view('admin.rtoOffics.index', compact('rtoOffics'));
    }

    public function create()
    {
        abort_if(Gate::denies('rto_offic_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $states = State::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.rtoOffics.create', compact('states'));
    }

    public function store(StoreRtoOfficRequest $request)
    {
        $rtoOffic = RtoOffic::create($request->all());

        return redirect()->route('admin.rto-offics.index');
    }

    public function edit(RtoOffic $rtoOffic)
    {
        abort_if(Gate::denies('rto_offic_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $states = State::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $rtoOffic->load('state');

        return view('admin.rtoOffics.edit', compact('rtoOffic', 'states'));
    }

    public function update(UpdateRtoOfficRequest $request, RtoOffic $rtoOffic)
    {
        $rtoOffic->update($request->all());

        return redirect()->route('admin.rto-offics.index');
    }

    public function show(RtoOffic $rtoOffic)
    {
        abort_if(Gate::denies('rto_offic_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rtoOffic->load('state');

        return view('admin.rtoOffics.show', compact('rtoOffic'));
    }

    public function destroy(RtoOffic $rtoOffic)
    {
        abort_if(Gate::denies('rto_offic_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rtoOffic->delete();

        return back();
    }

    public function massDestroy(MassDestroyRtoOfficRequest $request)
    {
        $rtoOffics = RtoOffic::find(request('ids'));

        foreach ($rtoOffics as $rtoOffic) {
            $rtoOffic->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
