<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroySellMembershipRequest;
use App\Http\Requests\StoreSellMembershipRequest;
use App\Http\Requests\UpdateSellMembershipRequest;
use App\Models\SellMembership;
use Gate;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;

class SellMembershipController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('sell_membership_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $sellMemberships = SellMembership::all();

        return view('admin.sellMemberships.index', compact('sellMemberships'));
    }

    public function create()
    {
        abort_if(Gate::denies('sell_membership_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.sellMemberships.create');
    }

    public function store(StoreSellMembershipRequest $request)
    {
        $sellMembership = SellMembership::create($request->all());

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $sellMembership->id]);
        }

        return redirect()->route('admin.sell-memberships.index');
    }

    public function edit(SellMembership $sellMembership)
    {
        abort_if(Gate::denies('sell_membership_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.sellMemberships.edit', compact('sellMembership'));
    }

    public function update(UpdateSellMembershipRequest $request, SellMembership $sellMembership)
    {
        $sellMembership->update($request->all());

        return redirect()->route('admin.sell-memberships.index');
    }

    public function show(SellMembership $sellMembership)
    {
        abort_if(Gate::denies('sell_membership_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.sellMemberships.show', compact('sellMembership'));
    }

    public function destroy(SellMembership $sellMembership)
    {
        abort_if(Gate::denies('sell_membership_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $sellMembership->delete();

        return back();
    }

    public function massDestroy(MassDestroySellMembershipRequest $request)
    {
        $sellMemberships = SellMembership::find(request('ids'));

        foreach ($sellMemberships as $sellMembership) {
            $sellMembership->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        abort_if(Gate::denies('sell_membership_create') && Gate::denies('sell_membership_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new SellMembership();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
}
