<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyServiceMembershipRequest;
use App\Http\Requests\StoreServiceMembershipRequest;
use App\Http\Requests\UpdateServiceMembershipRequest;
use App\Models\ServiceMembership;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class ServiceMembershipController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('service_membership_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $serviceMemberships = ServiceMembership::all();

        return view('admin.serviceMemberships.index', compact('serviceMemberships'));
    }

    public function create()
    {
        abort_if(Gate::denies('service_membership_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.serviceMemberships.create');
    }

    public function store(StoreServiceMembershipRequest $request)
    {
        $serviceMembership = ServiceMembership::create($request->all());

        return redirect()->route('admin.service-memberships.index');
    }

    public function edit(ServiceMembership $serviceMembership)
    {
        abort_if(Gate::denies('service_membership_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.serviceMemberships.edit', compact('serviceMembership'));
    }

    public function update(UpdateServiceMembershipRequest $request, ServiceMembership $serviceMembership)
    {
        $serviceMembership->update($request->all());

        return redirect()->route('admin.service-memberships.index');
    }

    public function show(ServiceMembership $serviceMembership)
    {
        abort_if(Gate::denies('service_membership_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.serviceMemberships.show', compact('serviceMembership'));
    }

    public function destroy(ServiceMembership $serviceMembership)
    {
        abort_if(Gate::denies('service_membership_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $serviceMembership->delete();

        return back();
    }

    public function massDestroy(MassDestroyServiceMembershipRequest $request)
    {
        $serviceMemberships = ServiceMembership::find(request('ids'));

        foreach ($serviceMemberships as $serviceMembership) {
            $serviceMembership->delete();
        }

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
