<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreAddServiceRequest;
use App\Http\Requests\UpdateAddServiceRequest;
use App\Http\Resources\Admin\AddServiceResource;
use App\Models\AddService;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class AddServiceApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('add_service_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new AddServiceResource(AddService::with(['category', 'subcategory', 'user', 'shops'])->get());
    }

    public function store(StoreAddServiceRequest $request)
    {
        $addService = AddService::create($request->all());

        return (new AddServiceResource($addService))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(AddService $addService)
    {
        abort_if(Gate::denies('add_service_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new AddServiceResource($addService->load(['category', 'subcategory', 'user', 'shops']));
    }

    public function update(UpdateAddServiceRequest $request, AddService $addService)
    {
        $addService->update($request->all());

        return (new AddServiceResource($addService))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(AddService $addService)
    {
        abort_if(Gate::denies('add_service_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $addService->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
