<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\StoreSellMembershipRequest;
use App\Http\Requests\UpdateSellMembershipRequest;
use App\Http\Resources\Admin\SellMembershipResource;
use App\Models\SellMembership;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class SellMembershipApiController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('sell_membership_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new SellMembershipResource(SellMembership::all());
    }

    public function store(StoreSellMembershipRequest $request)
    {
        $sellMembership = SellMembership::create($request->all());

        return (new SellMembershipResource($sellMembership))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(SellMembership $sellMembership)
    {
        abort_if(Gate::denies('sell_membership_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new SellMembershipResource($sellMembership);
    }

    public function update(UpdateSellMembershipRequest $request, SellMembership $sellMembership)
    {
        $sellMembership->update($request->all());

        return (new SellMembershipResource($sellMembership))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(SellMembership $sellMembership)
    {
        abort_if(Gate::denies('sell_membership_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $sellMembership->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
