<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreServiceMembershipRequest;
use App\Http\Requests\UpdateServiceMembershipRequest;
use App\Http\Resources\Admin\ServiceMembershipResource;
use App\Models\ServiceMembership;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class ServiceMembershipApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('service_membership_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new ServiceMembershipResource(ServiceMembership::all());
    }

    public function store(StoreServiceMembershipRequest $request)
    {
        $serviceMembership = ServiceMembership::create($request->all());

        return (new ServiceMembershipResource($serviceMembership))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(ServiceMembership $serviceMembership)
    {
        abort_if(Gate::denies('service_membership_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new ServiceMembershipResource($serviceMembership);
    }

    public function update(UpdateServiceMembershipRequest $request, ServiceMembership $serviceMembership)
    {
        $serviceMembership->update($request->all());

        return (new ServiceMembershipResource($serviceMembership))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(ServiceMembership $serviceMembership)
    {
        abort_if(Gate::denies('service_membership_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $serviceMembership->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
