<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use Gate;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Shop;
use Symfony\Component\HttpFoundation\Response;
use Illuminate\Support\Facades\Validator;

class ApiController extends Controller
{
  public function verifyPhone(Request $request)
  {
     $validator = Validator::make($request->all(), [
          'phone' => 'required|string|max:15',
         ]);

    if ($validator->fails()) {
    // Handle validation failure
        return response()->json(['errors'=>true,'message'=>'phone number is required']);
    }
    $user=User::where('phone',$request->phone)->first();
    $otp=1234;
    if(isset($user))
    {
        // $user->otp=$otp;
        $user->save();
        $token = $user->createToken('token')->plainTextToken;
        return response()->json(['errors'=>false,'data'=>$user,'otp'=>$otp,'token'=>$token,'message'=>'otp sent successfully']);
    }
    else
    {
        $user=User::create(['phone'=>$request->phone,'is_phone_verified'=>0,'type'=>$request->type]);
        $token = $user->createToken('token')->plainTextToken;
        return response()->json(['errors'=>false,'data'=>$user,'otp'=>$otp,'token'=>$token,'message'=>'otp sent successfully']);
    }
  }
  public function register(Request $request)
  {
    $validator = Validator::make($request->all(), [
        'phone' => 'required|string|max:15',
        'email' => 'required|string',
        'name' => 'required|string',
       ]);
    if ($validator->fails()) {
      return response()->json(['errors'=>true,'message'=>'fill all mandatory fields']);
    }
    $user=User::where('phone',$request->phone)->first();
    $user->name=$request->name;
    $user->email=$request->email;
    // if ($request->input('profile', false)) {
    //   $user->addMedia(storage_path('tmp/uploads/' . basename($request->input('profile'))))->toMediaCollection('profile');
    //  }

    // if ($media = $request->input('ck-media', false)) {
    //   Media::whereIn('id', $media)->update(['model_id' => $user->id]);
    // }
    $user->save();
    return response()->json(['errors'=>false,'data'=>$user, 'message'=>'account created successfully']);
  }
  public function AddBusinessDetail(Request $request)
  {
    $shop=Shop::create($request->all());
    if ($request->input('photos', false)) {
      $shop->addMedia(storage_path('tmp/uploads/' . basename($request->input('photos'))))->toMediaCollection('photos');
     }

    // if ($media = $request->input('ck-media', false)) {
    //   Media::whereIn('id', $media)->update(['model_id' => $user->id]);
    // }
    return response()->json(['errors'=>false,'data'=>$shop,'message'=>'shop registered']);
  }
  
  public function EditBusinessDetail(Request $request)
  {
    $shop=Shop::find($request->shop_id)->update($request->all());
    if ($request->input('photos', false)) {
      $shop->addMedia(storage_path('tmp/uploads/' . basename($request->input('photos'))))->toMediaCollection('photos');
     }

    // if ($media = $request->input('ck-media', false)) {
    //   Media::whereIn('id', $media)->update(['model_id' => $user->id]);
    // }
    return response()->json(['errors'=>false,'data'=>$shop,'message'=>'shop updated']);
  }

  public function getBusinessProfile()
  {
    $getdata=User::find(Auth::user()->id)
    ->with('getShops')
    ->get();
    return response()->json([
      'errors'=>false,
      'data'=>$getdata,
      'message'=>'Data successfully fetched'
    ]);
  }

  public function getprofile(Request $request)
  {
    $getdata=User::find(Auth::user()->id)
    ->with('vehicle')
    ->get();
    return response()->json([
      'errors'=>false,
      'data'=>$getdata,
      'message'=>'Data successfully fetched'
    ]);
  }

  public function homeData()
  {
    $banner=Banner::where('status',1)->get();
    $nearbyservice=ServiceCategory::where('status',1)
    ->orderBy('id', 'asc')
    ->limit(8)
    ->get();
    $nearbyShops=Shop::where('status',1)
    ->orderBy('id','asc')
    ->limit(6)
    ->get();
    $otherDetails=OtherDetail::where('status',1)->get();
    $usedCarsBikes=Category::with('products')->get();
    $data=['banner'=>$banner,
           'nearbyservice'=>$nearbyservice,
           'nearbyshops'=>$nearbyShops,
           'otherdetails'=>$otherDetails,
           'usedCarsBike'=>$usedCarsBikes];

    return response()->json(['errors'=>false,'data'=>$data,'message'=>'data fetched']);
  }

  public function categoryData(Request $request)
  {
    $categoryData=ServiceCategory::where('status',1)
    ->where('id',$request->category_id)
    ->first();
    $subcategory=ServiceSubcategory::where('status',1)
    ->where('category_id',$request->category_id)
    ->with('getShop')
    ->get();
    foreach($subcategory as $c)
     {
      $latlong=[];
       foreach($c->getShop as $v)
       {
         $fav=Favourite::where('shop_id',$v->id)->where('user_id',Auth::user()->id)->first();
         if($fav)
         {
          $v->fav=1;
         }
         else
         {
          $v->fav=0;
         }
         $latlong=array_push($latlong,['lat'=>$v->lat,'long'=>$v->long]);
       }
       $c->latlong=$latlong;
     }
    $data=[
        'category_data'=>$categoryData,
        'subcategory_data'=>$subcategory,
    ];
    return response()->json([
        'errors'=>false,
        'data'=>$data,
        'message'=>'fetched successfully'
    ]);
  }

  public function getNearbyUsedCars(Request $request)
  {
     $user_id=Auth::user()->id;
     $carbrands=Category::with('vehicle')
     ->get();
     $type=Type::where('status',1)
     ->get();
     foreach($carbrands as $c)
     {
      $latlong=[];
       foreach($c->vehicle as $v)
       {
         $fav=Favourite::wherw('vehicle_id',$v->id)->where('user_id',$use_id)->first();
         if($fav)
         {
          $v->fav=1;
         }
         else
         {
          $v->fav=0;
         }
         $latlong=array_push($latlong,['lat'=>$v->lat,'long'=>$v->long]);
       }
       $c->latlong=$latlong;
     }
     $data=[
      'type'=>$type,
      'carbrands'=>$carbrands
     ];
     return response()->json([

      'errors'=>false,
      'data'=>$data,
      'message'=>'fetched successfully'

     ]);
  }

  public function addVehicleFavourite(Request $request)
  {
     $fav=Favourite::where('user_id',$request->user_id)
     ->where('vehicle_id',$request->vehicle_id)
     ->first();
     if($fav)
     {
        $fav->delete();
        return response()->json([
            'errors'=>false,
            'message'=>'Removed from favourite'
        ]);
     }
     else
     {
        Favourite::create(['user_id'=>$request->user_id,
        'vehicle_id'=>$request->vehicle_id]);
        return response()->json([
            'errors'=>false,
            'message'=>'Added to favourite'
        ]);
     }
  }

  public function addShopFavourite(Request $request)
  {
     $fav=Favourite::where('user_id',$request->user_id)
     ->where('shop_id',$request->shop_id)
     ->first();
     if($fav)
     {
        $fav->delete();
        return response()->json([
            'errors'=>false,
            'message'=>'Removed from favourite'
        ]);
     }
     else
     {
        Favourite::create(['user_id'=>$request->user_id,
        'shop_id'=>$request->shop_id]);
        return response()->json([
            'errors'=>false,
            'message'=>'Added to favourite'
        ]);
     }
  }

  public function getFavData()
  {
    $user_id=Auth::user()->id;
    $shops=Favourite::with('shops')
    ->with('vehicle')
    ->where('user_id',$user_id)
    ->get();
    return response()->json([
      'errors'=>false,
      'data'=>$shops,
      'message'=>'data fetched successfully'
    ]);
  }

  public function getVehicle(Request $request)
  {
    $vehicle=Vehicle::find($request->vehicle_id);
    $getRelatedVehicle=Vehicle::where('category_id',$vehicle->category_id)
    ->orderBy('subcategory_id','asc')
    ->get();
    // if(count($getRelatedVehicle)>=11)
    // {
        
    // }
    $data=[
        'vehicle'=>$vehicle,
        'getrelatedvehicle'=>$getRelatedVehicle
    ];
    return response()->json([
        'errors'=>false,
        'data'=>$data,
        'message'=>'fetched successfully'
    ]);
  }

  public function getShop(Request $request)
  {
    $user_id=Auth::user()->id;
    $shop=Shop::find($request->shop_id)
    ->with('reviews')
    ->with('category')
    ->with('brands')
    ->with(['favourite'=>function($query) use ($user_id){
      $query->where('user_id', $user_id);
    }])->get();
    return response()->json([
      'errors'=>false,
      'data'=>$shop,
      'message'=>'fetched successfully'
    ]);
  }

  public function AddVehicle(Request $request)
  {
    $vehicle=Vehicle::create($request->all());
    if ($request->input('photos', false)) {
      $vehicle->addMedia(storage_path('tmp/uploads/' . basename($request->input('photos'))))->toMediaCollection('vehicle');
     }

    // if ($media = $request->input('ck-media', false)) {
    //   Media::whereIn('id', $media)->update(['model_id' => $user->id]);
    // }
    return response()->json(['errors'=>false,'data'=>$vehicle,'message'=>'vehicle registered']);
  }

  public function EditVehicle(Request $request)
  {
    $vehicle=Vehicle::find($request->vehicle_id)->update($request->all());
    if ($request->input('photos', false)) {
      $vehicle->addMedia(storage_path('tmp/uploads/' . basename($request->input('photos'))))->toMediaCollection('vehicle');
     }
    // if ($media = $request->input('ck-media', false)) {
    //   Media::whereIn('id', $media)->update(['model_id' => $user->id]);
    // }
    return response()->json(['errors'=>false,'data'=>$vehicle,'message'=>'vehicle registered']);
  }

}