<?php

namespace App\Models;

use DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Attribute extends Model
{
    use SoftDeletes, HasFactory;

    public $table = 'attributes';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public const STATUS_SELECT = [
        '0' => 'unpublish',
        '1' => 'publish',
        '2' => 'block',
    ];

    public const TYPE_SELECT = [
        '0' => 'select box',
        '1' => 'check box',
        '2' => 'input box',
        '3' => 'radio button',
    ];

    protected $fillable = [
        'name',
        'type',
        'vehicle_id',
        'status',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }

    public function vehicle()
    {
        return $this->belongsTo(Type::class, 'vehicle_id');
    }
}
