@extends('layouts.admin')
@section('content')

<div class="card">
    <div class="card-header">
        {{ trans('global.edit') }} {{ trans('cruds.addService.title_singular') }}
    </div>

    <div class="card-body">
        <form method="POST" action="{{ route("admin.add-services.update", [$addService->id]) }}" enctype="multipart/form-data">
            @method('PUT')
            @csrf
            <div class="form-group">
                <label for="category_id">{{ trans('cruds.addService.fields.category') }}</label>
                <select class="form-control select2 {{ $errors->has('category') ? 'is-invalid' : '' }}" name="category_id" id="category_id">
                    @foreach($categories as $id => $entry)
                        <option value="{{ $id }}" {{ (old('category_id') ? old('category_id') : $addService->category->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('category'))
                    <span class="text-danger">{{ $errors->first('category') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.addService.fields.category_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="subcategory_id">{{ trans('cruds.addService.fields.subcategory') }}</label>
                <select class="form-control select2 {{ $errors->has('subcategory') ? 'is-invalid' : '' }}" name="subcategory_id" id="subcategory_id">
                    @foreach($subcategories as $id => $entry)
                        <option value="{{ $id }}" {{ (old('subcategory_id') ? old('subcategory_id') : $addService->subcategory->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('subcategory'))
                    <span class="text-danger">{{ $errors->first('subcategory') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.addService.fields.subcategory_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="user_id">{{ trans('cruds.addService.fields.user') }}</label>
                <select class="form-control select2 {{ $errors->has('user') ? 'is-invalid' : '' }}" name="user_id" id="user_id">
                    @foreach($users as $id => $entry)
                        <option value="{{ $id }}" {{ (old('user_id') ? old('user_id') : $addService->user->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('user'))
                    <span class="text-danger">{{ $errors->first('user') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.addService.fields.user_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required">{{ trans('cruds.addService.fields.status') }}</label>
                <select class="form-control {{ $errors->has('status') ? 'is-invalid' : '' }}" name="status" id="status" required>
                    <option value disabled {{ old('status', null) === null ? 'selected' : '' }}>{{ trans('global.pleaseSelect') }}</option>
                    @foreach(App\Models\AddService::STATUS_SELECT as $key => $label)
                        <option value="{{ $key }}" {{ old('status', $addService->status) === (string) $key ? 'selected' : '' }}>{{ $label }}</option>
                    @endforeach
                </select>
                @if($errors->has('status'))
                    <span class="text-danger">{{ $errors->first('status') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.addService.fields.status_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="shops_id">{{ trans('cruds.addService.fields.shops') }}</label>
                <select class="form-control select2 {{ $errors->has('shops') ? 'is-invalid' : '' }}" name="shops_id" id="shops_id" required>
                    @foreach($shops as $id => $entry)
                        <option value="{{ $id }}" {{ (old('shops_id') ? old('shops_id') : $addService->shops->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('shops'))
                    <span class="text-danger">{{ $errors->first('shops') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.addService.fields.shops_helper') }}</span>
            </div>
            <div class="form-group">
                <button class="btn btn-danger" type="submit">
                    {{ trans('global.save') }}
                </button>
            </div>
        </form>
    </div>
</div>



@endsection