@extends('layouts.admin')
@section('content')

<div class="card">
    <div class="card-header">
        {{ trans('global.create') }} {{ trans('cruds.vehicle.title_singular') }}
    </div>

    <div class="card-body">
        <form method="POST" action="{{ route("admin.vehicles.store") }}" enctype="multipart/form-data">
            @csrf
            <div class="form-group">
                <label class="required" for="name">{{ trans('cruds.vehicle.fields.name') }}</label>
                <input class="form-control {{ $errors->has('name') ? 'is-invalid' : '' }}" type="text" name="name" id="name" value="{{ old('name', '') }}" required>
                @if($errors->has('name'))
                    <span class="text-danger">{{ $errors->first('name') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.name_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="category_id">{{ trans('cruds.vehicle.fields.category') }}</label>
                <select class="form-control select2 {{ $errors->has('category') ? 'is-invalid' : '' }}" name="category_id" id="category_id" required>
                    @foreach($categories as $id => $entry)
                        <option value="{{ $id }}" {{ old('category_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('category'))
                    <span class="text-danger">{{ $errors->first('category') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.category_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="attribute">{{ trans('Type') }}</label>
                <select class="form-control select2 {{ $errors->has('type') ? 'is-invalid' : '' }}" name="type" id="type" required>
                    @foreach($type as $id => $entry)
                        <option value="{{ $id }}" {{ old('type') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('type'))
                    <span class="text-danger">{{ $errors->first('type') }}</span>
                @endif
                <!-- <span class="help-block">{{ trans('cruds.vehicle.fields_helper') }}</span> -->
            <div>
            <br>
            <div id="dynamic-fields-container">
            </div>
            <div class="form-group">
                <label for="subcategory_id">{{ trans('cruds.vehicle.fields.subcategory') }}</label>
                <select class="form-control select2 {{ $errors->has('subcategory') ? 'is-invalid' : '' }}" name="subcategory_id" id="subcategory_id">
                    @foreach($subcategories as $id => $entry)
                        <option value="{{ $id }}" {{ old('subcategory_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('subcategory'))
                    <span class="text-danger">{{ $errors->first('subcategory') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.subcategory_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="photos">{{ trans('cruds.vehicle.fields.photos') }}</label>
                <div class="needsclick dropzone {{ $errors->has('photos') ? 'is-invalid' : '' }}" id="photos-dropzone">
                </div>
                @if($errors->has('photos'))
                    <span class="text-danger">{{ $errors->first('photos') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.photos_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="vehicle_price">{{ trans('cruds.vehicle.fields.vehicle_price') }}</label>
                <input class="form-control {{ $errors->has('vehicle_price') ? 'is-invalid' : '' }}" type="number" name="vehicle_price" id="vehicle_price" value="{{ old('vehicle_price', '') }}" step="0.01">
                @if($errors->has('vehicle_price'))
                    <span class="text-danger">{{ $errors->first('vehicle_price') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.vehicle_price_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="state">{{ trans('cruds.vehicle.fields.state') }}</label>
                <input class="form-control {{ $errors->has('state') ? 'is-invalid' : '' }}" type="text" name="state" id="state" value="{{ old('state', '') }}" required>
                @if($errors->has('state'))
                    <span class="text-danger">{{ $errors->first('state') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.state_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="city">{{ trans('cruds.vehicle.fields.city') }}</label>
                <input class="form-control {{ $errors->has('city') ? 'is-invalid' : '' }}" type="text" name="city" id="city" value="{{ old('city', '') }}" required>
                @if($errors->has('city'))
                    <span class="text-danger">{{ $errors->first('city') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.city_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="pincode">{{ trans('cruds.vehicle.fields.pincode') }}</label>
                <input class="form-control {{ $errors->has('pincode') ? 'is-invalid' : '' }}" type="text" name="pincode" id="pincode" value="{{ old('pincode', '') }}" required>
                @if($errors->has('pincode'))
                    <span class="text-danger">{{ $errors->first('pincode') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.pincode_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="registration_no">{{ trans('cruds.vehicle.fields.registration_no') }}</label>
                <input class="form-control {{ $errors->has('registration_no') ? 'is-invalid' : '' }}" type="text" name="registration_no" id="registration_no" value="{{ old('registration_no', '') }}">
                @if($errors->has('registration_no'))
                    <span class="text-danger">{{ $errors->first('registration_no') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.registration_no_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="lat">{{ trans('cruds.vehicle.fields.lat') }}</label>
                <input class="form-control {{ $errors->has('lat') ? 'is-invalid' : '' }}" type="number" name="lat" id="lat" value="{{ old('lat', '') }}" step="0.01">
                @if($errors->has('lat'))
                    <span class="text-danger">{{ $errors->first('lat') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.lat_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="long">{{ trans('cruds.vehicle.fields.long') }}</label>
                <input class="form-control {{ $errors->has('long') ? 'is-invalid' : '' }}" type="number" name="long" id="long" value="{{ old('long', '') }}" step="0.01">
                @if($errors->has('long'))
                    <span class="text-danger">{{ $errors->first('long') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.long_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="location">{{ trans('cruds.vehicle.fields.location') }}</label>
                <input class="form-control {{ $errors->has('location') ? 'is-invalid' : '' }}" type="text" name="location" id="location" value="{{ old('location', '') }}">
                @if($errors->has('location'))
                    <span class="text-danger">{{ $errors->first('location') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.location_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="shops_id">{{ trans('cruds.vehicle.fields.shops') }}</label>
                <select class="form-control select2 {{ $errors->has('shops') ? 'is-invalid' : '' }}" name="shops_id" id="shops_id" required>
                    @foreach($shops as $id => $entry)
                        <option value="{{ $id }}" {{ old('shops_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('shops'))
                    <span class="text-danger">{{ $errors->first('shops') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.shops_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="about_us">{{ trans('cruds.vehicle.fields.about_us') }}</label>
                <textarea class="form-control ckeditor {{ $errors->has('about_us') ? 'is-invalid' : '' }}" name="about_us" id="about_us">{!! old('about_us') !!}</textarea>
                @if($errors->has('about_us'))
                    <span class="text-danger">{{ $errors->first('about_us') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.about_us_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required">{{ trans('cruds.vehicle.fields.status') }}</label>
                <select class="form-control {{ $errors->has('status') ? 'is-invalid' : '' }}" name="status" id="status" required>
                    <option value disabled {{ old('status', null) === null ? 'selected' : '' }}>{{ trans('global.pleaseSelect') }}</option>
                    @foreach(App\Models\Vehicle::STATUS_SELECT as $key => $label)
                        <option value="{{ $key }}" {{ old('status', '1') === (string) $key ? 'selected' : '' }}>{{ $label }}</option>
                    @endforeach
                </select>
                @if($errors->has('status'))
                    <span class="text-danger">{{ $errors->first('status') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.status_helper') }}</span>
            </div>
            <!-- <div class="form-group">
                <label for="user_id">{{ trans('cruds.vehicle.fields.user') }}</label>
                <select class="form-control select2 {{ $errors->has('user') ? 'is-invalid' : '' }}" name="user_id" id="user_id">
                    @foreach($users as $id => $entry)
                        <option value="{{ $id }}" {{ old('user_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('user'))
                    <span class="text-danger">{{ $errors->first('user') }}</span>
                @endif
                <span class="help-block">{{ trans('cruds.vehicle.fields.user_helper') }}</span>
            </div> -->
            <input value="{{ Auth::user()->id }}" name="user_id" hidden>
            <div class="form-group">
                <button class="btn btn-danger" type="submit">
                    {{ trans('global.save') }}
                </button>
            </div>
        </form>
    </div>
</div>



@endsection

@section('scripts')
<script src="https://code.jquery.com/jquery-3.6.4.min.js"></script>
<script>
    var uploadedPhotosMap = {}
Dropzone.options.photosDropzone = {
    url: '{{ route('admin.vehicles.storeMedia') }}',
    maxFilesize: 2, // MB
    acceptedFiles: '.jpeg,.jpg,.png,.gif',
    addRemoveLinks: true,
    headers: {
      'X-CSRF-TOKEN': "{{ csrf_token() }}"
    },
    params: {
      size: 2,
      width: 4096,
      height: 4096
    },
    success: function (file, response) {
      $('form').append('<input type="hidden" name="photos[]" value="' + response.name + '">')
      uploadedPhotosMap[file.name] = response.name
    },
    removedfile: function (file) {
      console.log(file)
      file.previewElement.remove()
      var name = ''
      if (typeof file.file_name !== 'undefined') {
        name = file.file_name
      } else {
        name = uploadedPhotosMap[file.name]
      }
      $('form').find('input[name="photos[]"][value="' + name + '"]').remove()
    },
    init: function () {
@if(isset($vehicle) && $vehicle->photos)
      var files = {!! json_encode($vehicle->photos) !!}
          for (var i in files) {
          var file = files[i]
          this.options.addedfile.call(this, file)
          this.options.thumbnail.call(this, file, file.preview ?? file.preview_url)
          file.previewElement.classList.add('dz-complete')
          $('form').append('<input type="hidden" name="photos[]" value="' + file.file_name + '">')
        }
@endif
    },
     error: function (file, response) {
         if ($.type(response) === 'string') {
             var message = response //dropzone sends it's own error messages in string
         } else {
             var message = response.errors.file
         }
         file.previewElement.classList.add('dz-error')
         _ref = file.previewElement.querySelectorAll('[data-dz-errormessage]')
         _results = []
         for (_i = 0, _len = _ref.length; _i < _len; _i++) {
             node = _ref[_i]
             _results.push(node.textContent = message)
         }

         return _results
     }
}

</script>
<script>
    $(document).ready(function () {

        $('#type').change(function (event) {
            // Get form data
            var formData = $(this).val();
            // alert(formData);

            // Make AJAX POST request using jQuery
            $.ajax({
                type: 'POST',
                headers: {
                    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                },
                url: '{{ route('admin.getAttributes') }}',
                data: {type:formData},
                dataType: 'json',
                success: function (response) {
                    console.log(response);
                    //  alert(response.data[0].type);
                    // Function to create a select box
    // Loop through the array and create dynamic fields
               for (var i = 0; i < response.data.length; i++) {
                var fieldType = response.data[i].type;
                var field='';
                switch (parseInt(fieldType)) {
                  case 0:
                    field = createSelectBox(response.data[i]);
                    break;
                  case 2:
                    field = createInputBox(response.data[i]);
                    break;
                  case 3:
                    field = createRadioButton(response.data[i]);
                    break;
                  case 1:
                    field = createCheckBox(response.data[i]);
                    break;
                  default:
                    field = $('<p>Unsupported field type</p>');
                }
                //  alert(field);
                 $('#dynamic-fields-container').append(field);
                }
                    // Handle the response as needed
                },
                error: function (error) {
                    console.error(error);
                    // Handle errors
                }
            });
        });

    // Function to create a select box
    function createSelectBox(data) {
      return $('<div class="form-group"><label for="about_us">'+data.name+'</label><select class="form-control" name="'+data.name+'"><option value="option1">Option 1</option><option value="option2">Option 2</option></select></div>');
    }

    // Function to create an input box
    function createInputBox(data) {
      return $('<div class="form-group"><label for="about_us">'+data.name+'</label><input class="form-control" name="'+data.name+'" type="text" placeholder="'+data.name+'"></div>');
    }

    // Function to create a radio button
    function createRadioButton(data) {
      return $('<div class="form-group"><label for="about_us">'+data.name+'</label><input class="form-control" name="'+data.name+'" type="radio" name="radioGroup"></div>');
    }

    // Function to create a checkbox
    function createCheckBox(data) {
      return $('<div class="form-group"><label for="about_us">'+data.name+'</label><input class="form-control" name="'+data.name+'" type="checkbox"></div>');
    }

  function SimpleUploadAdapter(editor) {
    editor.plugins.get('FileRepository').createUploadAdapter = function(loader) {
      return {
        upload: function() {
          return loader.file
            .then(function (file) {
              return new Promise(function(resolve, reject) {
                // Init request
                var xhr = new XMLHttpRequest();
                xhr.open('POST', '{{ route('admin.vehicles.storeCKEditorImages') }}', true);
                xhr.setRequestHeader('x-csrf-token', window._token);
                xhr.setRequestHeader('Accept', 'application/json');
                xhr.responseType = 'json';

                // Init listeners
                var genericErrorText = `Couldn't upload file: ${ file.name }.`;
                xhr.addEventListener('error', function() { reject(genericErrorText) });
                xhr.addEventListener('abort', function() { reject() });
                xhr.addEventListener('load', function() {
                  var response = xhr.response;

                  if (!response || xhr.status !== 201) {
                    return reject(response && response.message ? `${genericErrorText}\n${xhr.status} ${response.message}` : `${genericErrorText}\n ${xhr.status} ${xhr.statusText}`);
                  }

                  $('form').append('<input type="hidden" name="ck-media[]" value="' + response.id + '">');

                  resolve({ default: response.url });
                });

                if (xhr.upload) {
                  xhr.upload.addEventListener('progress', function(e) {
                    if (e.lengthComputable) {
                      loader.uploadTotal = e.total;
                      loader.uploaded = e.loaded;
                    }
                  });
                }

                // Send request
                var data = new FormData();
                data.append('upload', file);
                data.append('crud_id', '{{ $vehicle->id ?? 0 }}');
                xhr.send(data);
              });
            })
        }
      };
    }
  }

  var allEditors = document.querySelectorAll('.ckeditor');
  for (var i = 0; i < allEditors.length; ++i) {
    ClassicEditor.create(
      allEditors[i], {
        extraPlugins: [SimpleUploadAdapter]
      }
    );
  }
});
</script>

@endsection